@@ -1,7 +1,3 @@
-#' @import rlang
-#' @keywords internal
-"_PACKAGE"
-
 .onLoad <- function(...) {
   run_on_load()
 }
