@@ -21,4 +21,21 @@ def first_n(n):
     out <- c(out, x)
   })
   expect_equal(out, 1:3)
+
+
 })
+
+
+test_that("can use reticulate iteratables", {
+  skip_if_not_installed("reticulate")
+  skip_on_cran()
+  skip_on_ci()
+
+  i <- 0L
+  loop(for (el in reticulate::py_eval("range(3)")) {
+    i <- i + el
+  })
+  expect_equal(i, 3L)
+})
+
+
